OC.L10N.register(
    "core",
    {
    "No image or file provided" : "Nijedna slika ili datoteka nije dobavljena",
    "Unknown filetype" : "Vrsta datoteke nepoznata",
    "Invalid image" : "Slika neispravna",
    "No temporary profile picture available, try again" : "Slike privremenih profila nisu dostupne, pokušajte ponovno",
    "No crop data provided" : "Nema podataka o obrezivanju",
    "Couldn't reset password because the token is invalid" : "Resetiranje lozinke nije moguće jer je token neispravan.",
    "%s password reset" : "%s lozinka resetirana",
    "Couldn't send reset email. Please contact your administrator." : "Nije mogće poslati resetiranu poštu. MOlimo kontaktirajte svog administratora.",
    "Couldn't send mail to following users: %s " : "Nije moguće slanje pošte sljedećim korisnicima: %s",
    "Turned on maintenance mode" : "Način rada za održavanje uključen",
    "Turned off maintenance mode" : "Način rada za održavanje isključen",
    "Updated database" : " Baza podataka ažurirana",
    "Checked database schema update" : "Provjereno ažuriranje sheme  baze podataka",
    "Checked database schema update for apps" : "Provjereno ažuriranje sheme baze podataka za aplikacije",
    "Updated \"%s\" to %s" : "Ažurirano \"%s\" u %s",
    "Sunday" : "Nedjelja",
    "Monday" : "Ponedjeljak",
    "Tuesday" : "Utorak",
    "Wednesday" : "Srijeda",
    "Thursday" : "Četvrtak",
    "Friday" : "Petak",
    "Saturday" : "Subota",
    "Sun." : "ned.",
    "Mon." : "pon.",
    "Tue." : "ut.",
    "Wed." : "sri.",
    "Thu." : "čet.",
    "Fri." : "pet.",
    "Sat." : "sub.",
    "January" : "Siječanj",
    "February" : "Veljača",
    "March" : "Ožujak",
    "April" : "Travanj",
    "May" : "Svibanj",
    "June" : "Lipanj",
    "July" : "Srpanj",
    "August" : "Kolovoz",
    "September" : "Rujan",
    "October" : "Listopad",
    "November" : "Studeni",
    "December" : "Prosinac",
    "Jan." : "sij.",
    "Feb." : "velj.",
    "Mar." : "ož.",
    "Apr." : "trav.",
    "May." : "svib.",
    "Jun." : "lip.",
    "Jul." : "srp.",
    "Aug." : "kol.",
    "Sep." : "ruj.",
    "Oct." : "list.",
    "Nov." : "stud.",
    "Dec." : "pros.",
    "Settings" : "Postavke",
    "Saving..." : "Spremanje...",
    "Dismiss" : "Odpusti",
    "seconds ago" : "prije par sekundi",
    "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "Veza za resetiranje vaše lozinke poslana je na vašu adresu e-pošte. Ako je ne primite unekom razumnom vremenskom roku, provjerite svoje spam/junk mape. <br> Ako nije tamo, kontaktirajtesvoga lokalnog administratora.",
    "Your files are encrypted. If you haven't enabled the recovery key, there will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "Vaše datoteke su šifrirane. Ako niste aktivirali ključ oporavka,svoje podatke nećete moći dohvatitinakon što vaša lozinka bude resetirana.<br />Ako ne znate što učiniti, prije nego linastavite, molimo kontaktirajte svog administratora. <br />Želite li doista nastaviti?",
    "I know what I'm doing" : "Znam što radim",
    "Password can not be changed. Please contact your administrator." : "Lozinku nije moguće promijeniti. Molimo kontaktirajte svog administratora.",
    "No" : "Ne",
    "Yes" : "Da",
    "Choose" : "Odaberite",
    "Error loading file picker template: {error}" : "Pogrešno učitavanje predloška za pronalazača datoteke: {error}",
    "Ok" : "Ok",
    "Error loading message template: {error}" : "Pogrešno učitavanje predloška za poruke: {error}",
    "read-only" : "samo čitanje",
    "_{count} file conflict_::_{count} file conflicts_" : ["neželjeno podudaranje u {count} datoteci","neželjeno podudaranje u {count} datoteke","neželjeno podudaranje u {count} datoteke"],
    "One file conflict" : "Konflikt u jednoj datoteci",
    "New Files" : "Nove datoteke",
    "Already existing files" : "Postojeće datoteke",
    "Which files do you want to keep?" : "Koje datoteke želite zadržati?",
    "If you select both versions, the copied file will have a number added to its name." : "Ako odaberete obje verzije, kopirana će datoteka uz svoje ime imati i broj.",
    "Cancel" : "Odustani",
    "Continue" : "Nastavi",
    "(all selected)" : "(sve odabrano)",
    "({count} selected)" : "({count} odabran)",
    "Error loading file exists template" : "Pogrešno učitavanje predloška DATOTEKA POSTOJI",
    "Very weak password" : "Lozinka vrlo slaba",
    "Weak password" : "Lozinka Slaba",
    "So-so password" : "Lozinka tako-tako",
    "Good password" : "Lozinka dobra",
    "Strong password" : "Lozinka snažna",
    "Error occurred while checking server setup" : "Greška prilikom provjeri postavki servera",
    "Shared" : "Resurs podijeljen",
    "Shared with {recipients}" : "Resurs podijeljen s {recipients}",
    "Error" : "Pogreška",
    "Error while sharing" : "Pogreška pri dijeljenju",
    "Error while unsharing" : "Pogreška pri prestanku dijeljenja",
    "The public link will expire no later than {days} days after it is created" : " Javna veza ističe najkasnije {days} dana nakon što je kreirana",
    "Set expiration date" : "Odredite datum isteka",
    "Expiration" : "Istjeće",
    "Expiration date" : "Datum isteka",
    "Link" : "Poveznica",
    "Edit" : "Uređivanje",
    "Remove" : "Makni",
    "Choose a password for the public link" : "Odaberite lozinku za javnu vezu",
    "Password" : "Lozinka",
    "Name" : "Naziv",
    "Allow editing" : "Omogući uređivanje",
    "Save" : "Spremi",
    "Sending ..." : "Slanje...",
    "Email sent" : "E-pošta poslana",
    "Email link to person" : "Pošaljite osobi vezu e-poštom",
    "Shared with you and the group {group} by {owner}" : "Dijeljeno s vama i grupom {group} vlasnika {owner}",
    "Shared with you by {owner}" : "S vama podijelio {owner}",
    "group" : "Grupa",
    "remote" : "na daljinu",
    "notify by email" : "Obavijestite e-poštom",
    "Unshare" : "Prestanite dijeliti",
    "can share" : "Dijeljenje moguće",
    "can edit" : "Uređivanje moguće",
    "create" : "Kreirajte",
    "change" : "promijeni",
    "delete" : "Izbrišite",
    "access control" : "Kontrola pristupa",
    "Share" : "Podijelite",
    "Resharing is not allowed" : "Ponovno dijeljenje nije dopušteno",
    "Share with people on other ownClouds using the syntax username@example.com/owncloud" : "Podijelite sa korisnicima drugoga ownClouda koristeći format korisnickoime@primjer.com/owncloud",
    "Warning" : "Upozorenje",
    "Delete" : "Izbrišite",
    "Rename" : "Preimenujte",
    "The object type is not specified." : "Vrsta objekta nije specificirana.",
    "Enter new" : "Unesite novi",
    "Add" : "Dodajte",
    "Edit tags" : "Uredite oznake",
    "Error loading dialog template: {error}" : "Pogrešno učitavanje predloška dijaloga: {error}",
    "No tags selected for deletion." : "Nijedna oznaka nije odabrana za brisanje.",
    "unknown text" : "nepoznati tekst",
    "Hello world!" : "Pozdrav svijete!",
    "sunny" : "sunčano",
    "Hello {name}, the weather is {weather}" : "Pozdrav {name}, vrijeme je {weather}",
    "Hello {name}" : "Pozdrav  {name}",
    "_download %n file_::_download %n files_" : ["preuzimanje %n datoteke","preuzimanje %n datoteke","preuzimanje %n datoteka"],
    "Please reload the page." : "Molimo, ponovno učitajte stranicu",
    "The update was successful. Redirecting you to ownCloud now." : "Ažuriranje je uspjelo. Upravo ste preusmjeravani na ownCloud.",
    "Searching other places" : "Pretraživanje drugih lokacija",
    "Personal" : "Osobno",
    "Users" : "Korisnici",
    "Apps" : "Aplikacije",
    "Admin" : "Admin",
    "Help" : "Pomoć",
    "Access forbidden" : "Pristup zabranjen",
    "File not found" : "Datoteka nije pronađena",
    "The specified document has not been found on the server." : "Traženi dokument nije pronađen na poslužitelju.",
    "You can click here to return to %s." : "Kliknite ovdje da se vratite na %s.",
    "Hey there,\n\njust letting you know that %s shared %s with you.\nView it: %s\n\n" : "Hej, \n\nsamo vam javljamo da je %s podijelio %s s vama.\nPogledajte ga: %s\n\n",
    "The share will expire on %s." : "Podijeljeni resurs će isteći na %s.",
    "Cheers!" : "Cheers!",
    "Internal Server Error" : "Pogreška poslužitelja.",
    "The server encountered an internal error and was unable to complete your request." : "Poslužitelj je naišao na grešku i nije u mogućnosti izvršiti Vaš zahtjev.",
    "Please contact the server administrator if this error reappears multiple times, please include the technical details below in your report." : "Molimo kontaktirajte svojeg administratora ako se ova greška učestalo pojavljuje, molimo da uključite i tehničke detalje ispod u svojem izvješću.",
    "More details can be found in the server log." : "Više podatake može se naći u logovima na poslužitelju.",
    "Technical details" : "Tehnički detalji",
    "Remote Address: %s" : "Udaljena adresa: %s",
    "Request ID: %s" : "Zahtjev ID: %s",
    "Code: %s" : "Kod: %s",
    "Message: %s" : "Poruka: %s",
    "File: %s" : "Datoteka: %s",
    "Line: %s" : "Red: %s",
    "Trace" : "Prati",
    "Create an <strong>admin account</strong>" : "Kreirajte <strong>admin račun</strong>",
    "Username" : "Korisničko ime",
    "Storage & database" : "Pohrana & baza podataka",
    "Data folder" : "Mapa za podatke",
    "Configure the database" : "Konfigurirajte bazu podataka",
    "Only %s is available." : "Jedino je %s dostupan.",
    "Database user" : "Korisnik baze podataka",
    "Database password" : "Lozinka baze podataka",
    "Database name" : "Naziv baze podataka",
    "Database tablespace" : "Tablespace (?) baze podataka",
    "Database host" : "Glavno računalo baze podataka",
    "Finish setup" : "Završite postavljanje",
    "Finishing …" : "Završavanje...",
    "Hey there,<br><br>just letting you know that %s shared <strong>%s</strong> with you.<br><a href=\"%s\">View it!</a><br><br>" : "Hej, <br><br> vam upravo javlja da je %s podijelio <strong>%s</strong>s vama.<br><a href=\"%s\">POgledajte!</a><br><br>",
    "Log out" : "Odjavite se",
    "Search" : "pretraži",
    "Server side authentication failed!" : "Autentikacija na strani poslužitelja nije uspjela!",
    "Please contact your administrator." : "Molimo kontaktirajte svog administratora.",
    "Log in" : "Prijavite se",
    "Alternative Logins" : "Alternativne prijave",
    "Use the following link to reset your password: {link}" : "Za resetiranje svoje lozinke koristite sljedeću vezu: {link}",
    "New password" : "Nova lozinka",
    "New Password" : "Nova lozinka",
    "Reset password" : "Resetirajte lozinku",
    "This ownCloud instance is currently in single user mode." : "Ova ownCloud instanca je trenutno u načinu rada za jednog korisnika.",
    "This means only administrators can use the instance." : "To znači da tu instancu mogu koristiti samo administratori.",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "Kontaktirajte svog administratora sustava ako se ova poruka ponavlja ili sepojavila neočekivano.",
    "Thank you for your patience." : "Hvala vam na strpljenju",
    "You are accessing the server from an untrusted domain." : "Poslužitelju pristupate iz nepouzdane domene.",
    "Depending on your configuration, as an administrator you might also be able to use the button below to trust this domain." : "Ovisno o vašoj konfiguraciji, kao administrator vi biste također mogli koristitigumb dolje za pristup toj domeni.",
    "Add \"%s\" as trusted domain" : "Dodajte \"%s\" kao pouzdanu domenu.",
    "The theme %s has been disabled." : "Tema %s je onemogućena",
    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Prije nego li nastavite, molimo osigurajte da su baza podataka, mapa konfiguracije i mapaza podatke sigurnosno kopirani.",
    "Start update" : "Započnite ažuriranje",
    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Da biste izbjegli vremensko prekoračenje s većim instalacijama, možete pokrenutisljedeću naredbu iz svoga instalacijskog direktorija:",
    "This page will refresh itself when the %s instance is available again." : "Stranica će se sama osvježiti kada %s bude ponovo dostupno.",
    "Menu" : "Meni",
    "Imprint" : "Otisak"
},
"nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;");
